==> projectx-sdk-1.1.46-sources.jar: cn/com/duiba/projectx/sdk/MQConsumerApi.java <==
package cn.com.duiba.projectx.sdk;

import cn.com.duiba.projectx.sdk.data.CreditsParamData;
import cn.com.duiba.projectx.sdk.data.Option;
import cn.com.duiba.projectx.sdk.playway.base.PrizeStock;
import cn.com.duiba.projectx.sdk.timerapis.ComponentTimerApi;
import cn.com.duiba.projectx.sdk.utils.*;

import java.security.KeyStore;
import java.util.Date;
import java.util.List;

/**
 * @Author: DSG
 * @Date: 15:45 2021/7/12
 * @Description: 消息接收方法下的api
 */
public interface MQConsumerApi {
    /**
     * 直接发奖，不通过发奖规则进行发奖
     *
     * @param strategyId
     * @param userId
     * @param prizeId
     * @return
     * @deprecated 使用TimerApi.sendPrize()方法
     */
    @Deprecated
    boolean sendPrizeWithDirect(String strategyId,String userId,String prizeId);

    /**
     * 直接发奖，不通过发奖规则进行发奖
     * @param strategyId 策略id
     * @param userId userId
     * @param prizeId prizeId
     * @return SendPrizeResult
     */
    SendPrizeResult sendPrize(String strategyId, String userId, String prizeId);

    /**
     * 直接给用户增加积分
     * 没有用户中奖记录
     * 如果发放失败则抛运行时异常
     * @param userId 用户id 不能为空
     * @param quantity 积分数量 不能为空
     * @param description 描述，需要定制时通过该参数, 可以为空
     */
    void sendCreditsPrize(String userId, Long quantity, String description);
    void sendCreditsPrize(String userId, Long quantity, String description, String transfer);

    /**
     * 获取运营配置的变量Integer
     *
     * @param key 配置项Variable
     * @return 变量对应的int值
     */
    Integer getIntVariable(String key);

    /**
     * 获取运营配置变量String
     *
     * @param key 配置项Variable
     * @return 变量对应的String值
     */
    String getStringVariable(String key);

    /**
     * 获取运营配置变量 image类型
     * @param key
     * @return
     */
    String getImageVariable(String key);

    /**
     * 获取kv记录
     *
     * @param key
     * @return
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#get(String)}
     */
    @Deprecated
    String getKvStringData(String key);

    /**
     * 添加/更新KV记录
     *
     * @param key
     * @param value
     * @param expireTime
     * @return
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#set(String, String, ExpireTime)}
     */
    @Deprecated
    boolean putKvStringData(String key, String value, Date expireTime);


    /**
     * 增加/减少数值
     *
     * @param key
     * @param offset 增量
     * @param expire 失效时间
     * @return 变更后的数值
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#increase(String, long, ExpireTime)}
     */
    @Deprecated
    long increase(String key, long offset, Date expire);


    /**
     * 获取kv中的数值
     *
     * @param key
     * @return 当值不存在时返回null，存在时返回实际数值
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#getLong(String)}
     */
    @Deprecated
    Long getKvLong(String key);


    /**
     * 给用户发放道具
     * @param userId userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(String userId, String spId, int quantity);

    /**
     * 消耗用户道具
     * @param userId
     * @param spId
     * @param quantity
     * @return
     */
    Boolean consumeStageProperty(String userId, String spId, int quantity);

    Long getSomebodyStageProperty(String userId, String spId);

    /**
     * 获取白名单用户list
     *
     * @param groupId 白名单分组ID
     * @return
     */
    List<String> getWhiteUserIdsByGroup(String groupId);

    /**
     * 获取一个QueryTable实例
     *
     * @param group 数据分组
     * @param clazz 映射类型
     * @param <T>
     * @return
     */
    <T extends Field> QueryTable<T> getTable(String group, Class<T> clazz);

    /**
     * 获取某个发奖策略下的所有奖项
     * @param strategyId 发奖策略id
     * @return 奖项列表
     */
    List<Option> queryOptions(String strategyId);

    /**
     * 获取一个http请求实例,不同project之间相互隔离
     *
     * @return
     */
    HttpHelper getHttpHelper();

    /**
     * 获取一个https请求实例
     *
     * @param name     实例的名称，不同实例间隔离
     * @param keyStore 证书
     * @return
     */
    HttpHelper getHttpHelper(String name, KeyStore keyStore);

    /**
     * 获取通知api
     *
     * @return
     */
    NotifyApi getNotifyApi();

    /**
     * 获取key-value存储功能API
     *
     * @return
     */
    KeyValueApi getKeyValueApi();

    DuibaApi getDuibaApi();

    UserRelationApi getUserRelationApi();

    /**
     * 扣减拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口扣减拖管积分
     * @param creditsParamData
     * @return
     */
    Boolean subTrustCredits(CreditsParamData creditsParamData);

    /**
     * 增加拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口增加拖管积分
     * @param creditsParamData
     * @return
     */
    Boolean addTrustCredits(CreditsParamData creditsParamData);

    /**
     * 查询拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口查询拖管积分
     * @param userId
     * @return
     */
    Long queryTrustCreditsByConsumerId(String userId);

    /**
     * 返回projectId
     * @return
     */
    String getProjectId();

    /**
     * 获取指定奖品库存信息
     * @return
     */
    PrizeStock getPrizeStock(String prizeId);

    /**
     * 获取组件Api
     */
    ComponentTimerApi getComponentTimerApi();

    /**
     * 获取缓存Api
     * @return
     */
    RedisApi getRedisApi();

    /**
     * 获取QueryTableSp实例
     * @param clazz 数据模型class对象
     * @param <T> 数据模型类型
     * @return 实例
     */
    <T> QueryTableSp<T> getQueryTableSp(Class<T> clazz);
}

==> projectx-sdk-1.1.63-sources.jar: cn/com/duiba/projectx/sdk/MQConsumerApi.java <==
package cn.com.duiba.projectx.sdk;

import cn.com.duiba.projectx.sdk.data.CreditsParamData;
import cn.com.duiba.projectx.sdk.data.Option;
import cn.com.duiba.projectx.sdk.playway.base.PrizeStock;
import cn.com.duiba.projectx.sdk.template.DistributedLock;
import cn.com.duiba.projectx.sdk.timerapis.ComponentTimerApi;
import cn.com.duiba.projectx.sdk.utils.*;

import java.security.KeyStore;
import java.util.Date;
import java.util.List;

/**
 * @Author: DSG
 * @Date: 15:45 2021/7/12
 * @Description: 消息接收方法下的api
 */
public interface MQConsumerApi {
    /**
     * 直接发奖，不通过发奖规则进行发奖
     *
     * @param strategyId
     * @param userId
     * @param prizeId
     * @return
     * @deprecated 使用TimerApi.sendPrize()方法
     */
    @Deprecated
    boolean sendPrizeWithDirect(String strategyId,String userId,String prizeId);

    /**
     * 直接发奖，不通过发奖规则进行发奖
     * @param strategyId 策略id
     * @param userId userId
     * @param prizeId prizeId
     * @return SendPrizeResult
     */
    SendPrizeResult sendPrize(String strategyId, String userId, String prizeId);

    /**
     * 直接给用户增加积分
     * 没有用户中奖记录
     * 如果发放失败则抛运行时异常
     * @param userId 用户id 不能为空
     * @param quantity 积分数量 不能为空
     * @param description 描述，需要定制时通过该参数, 可以为空
     */
    void sendCreditsPrize(String userId, Long quantity, String description);
    void sendCreditsPrize(String userId, Long quantity, String description, String transfer);

    /**
     * 获取运营配置的变量Integer
     *
     * @param key 配置项Variable
     * @return 变量对应的int值
     */
    Integer getIntVariable(String key);

    /**
     * 获取运营配置变量String
     *
     * @param key 配置项Variable
     * @return 变量对应的String值
     */
    String getStringVariable(String key);

    /**
     * 获取运营配置变量 image类型
     * @param key
     * @return
     */
    String getImageVariable(String key);

    /**
     * 获取kv记录
     *
     * @param key
     * @return
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#get(String)}
     */
    @Deprecated
    String getKvStringData(String key);

    /**
     * 添加/更新KV记录
     *
     * @param key
     * @param value
     * @param expireTime
     * @return
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#set(String, String, ExpireTime)}
     */
    @Deprecated
    boolean putKvStringData(String key, String value, Date expireTime);


    /**
     * 增加/减少数值
     *
     * @param key
     * @param offset 增量
     * @param expire 失效时间
     * @return 变更后的数值
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#increase(String, long, ExpireTime)}
     */
    @Deprecated
    long increase(String key, long offset, Date expire);


    /**
     * 获取kv中的数值
     *
     * @param key
     * @return 当值不存在时返回null，存在时返回实际数值
     * @deprecated {@link TimerApi#getKeyValueApi()} {@link KeyValueApi#getLong(String)}
     */
    @Deprecated
    Long getKvLong(String key);


    /**
     * 给用户发放道具
     * @param userId userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(String userId, String spId, int quantity);

    /**
     * 消耗用户道具
     * @param userId
     * @param spId
     * @param quantity
     * @return
     */
    Boolean consumeStageProperty(String userId, String spId, int quantity);

    Long getSomebodyStageProperty(String userId, String spId);

    /**
     * 获取白名单用户list
     *
     * @param groupId 白名单分组ID
     * @return
     */
    List<String> getWhiteUserIdsByGroup(String groupId);

    /**
     * 获取一个QueryTable实例
     *
     * @param group 数据分组
     * @param clazz 映射类型
     * @param <T>
     * @return
     */
    <T extends Field> QueryTable<T> getTable(String group, Class<T> clazz);

    /**
     * 获取某个发奖策略下的所有奖项
     * @param strategyId 发奖策略id
     * @return 奖项列表
     */
    List<Option> queryOptions(String strategyId);

    /**
     * 获取一个http请求实例,不同project之间相互隔离
     *
     * @return
     */
    HttpHelper getHttpHelper();

    /**
     * 获取一个https请求实例
     *
     * @param name     实例的名称，不同实例间隔离
     * @param keyStore 证书
     * @return
     */
    HttpHelper getHttpHelper(String name, KeyStore keyStore);

    /**
     * 获取通知api
     *
     * @return
     */
    NotifyApi getNotifyApi();

    /**
     * 获取key-value存储功能API
     *
     * @return
     */
    KeyValueApi getKeyValueApi();

    DuibaApi getDuibaApi();

    UserRelationApi getUserRelationApi();

    /**
     * 扣减拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口扣减拖管积分
     * @param creditsParamData
     * @return
     */
    Boolean subTrustCredits(CreditsParamData creditsParamData);

    /**
     * 增加拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口增加拖管积分
     * @param creditsParamData
     * @return
     */
    Boolean addTrustCredits(CreditsParamData creditsParamData);

    /**
     * 查询拖管积分
     * 注意：此方法只针对兑吧拖管积分
     * 调credits-center接口查询拖管积分
     * @param userId
     * @return
     */
    Long queryTrustCreditsByConsumerId(String userId);

    /**
     * 返回projectId
     * @return
     */
    String getProjectId();

    /**
     * 获取指定奖品库存信息
     * @return
     */
    PrizeStock getPrizeStock(String prizeId);

    /**
     * 获取组件Api
     */
    ComponentTimerApi getComponentTimerApi();

    /**
     * 获取缓存Api
     * @return
     */
    RedisApi getRedisApi();

    /**
     * 获取QueryTableSp实例
     * @param clazz 数据模型class对象
     * @param <T> 数据模型类型
     * @return 实例
     */
    <T> QueryTableSp<T> getQueryTableSp(Class<T> clazz);

    /**
     * 创建一个分布式锁对象
     *
     * @param expireSeconds 自动失效时间
     * @param key           自定义key（String realKey = "LK_" + getProjectId() + "_" + key;）
     * @return {@link DistributedLock}
     */
    DistributedLock newLock(String key, int expireSeconds);
}
